"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from dataclasses_json import Undefined, dataclass_json
from shippo import utils


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class CarrierAccountDHLExpressCreateRequestParameters:
    user_accepted_terms_and_conditions: bool = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('user_accepted_terms_and_conditions') }})
    r"""Whether or not the user agrees to the DHL Express Terms and Conditions. If passed in as false, request will fail with error 400"""
    

