"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum

class LabelFileTypeEnum(str, Enum):
    r"""Print format of the <a href=\\"https://docs.goshippo.com/docs/shipments/shippinglabelsizes/\\">label</a>. If empty, will use the default format set from
    <a href=\"https://apps.goshippo.com/settings/labels\">the Shippo dashboard.</a>
    """
    PNG = 'PNG'
    PNG_2_3X7_5 = 'PNG_2.3x7.5'
    PDF = 'PDF'
    PDF_2_3X7_5 = 'PDF_2.3x7.5'
    PDF_4X6 = 'PDF_4x6'
    PDF_4X8 = 'PDF_4x8'
    PDF_A4 = 'PDF_A4'
    PDF_A5 = 'PDF_A5'
    PDF_A6 = 'PDF_A6'
    ZPLII = 'ZPLII'
