"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum

class CustomsDeclarationB13AFilingOptionEnum(str, Enum):
    r"""B13A Option details are obtained by filing a B13A Canada Export Declaration via the Canadian Export Reporting System (CERS).
    <a href=\"https://www.cbsa-asfc.gc.ca/services/export/guide-eng.html\" target=\"_blank\" rel=\"noopener noreferrer\"> More information on reporting commercial exports from Canada. </a>
    """
    FILED_ELECTRONICALLY = 'FILED_ELECTRONICALLY'
    SUMMARY_REPORTING = 'SUMMARY_REPORTING'
    NOT_REQUIRED = 'NOT_REQUIRED'
