"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from enum import Enum
from typing import Optional


@dataclasses.dataclass
class GetCarrierRegistrationStatusGlobals:
    shippo_api_version: Optional[str] = dataclasses.field(default=None, metadata={'header': { 'field_name': 'SHIPPO-API-VERSION', 'style': 'simple', 'explode': False }})
    r"""String used to pick a non-default API version to use"""
    


class Carrier(str, Enum):
    r"""filter by specific carrier"""
    UPS = 'ups'
    USPS = 'usps'
    CANADA_POST = 'canada_post'


@dataclasses.dataclass
class GetCarrierRegistrationStatusRequest:
    carrier: Carrier = dataclasses.field(metadata={'query_param': { 'field_name': 'carrier', 'style': 'form', 'explode': True }})
    r"""filter by specific carrier"""
    shippo_api_version: Optional[str] = dataclasses.field(default=None, metadata={'header': { 'field_name': 'SHIPPO-API-VERSION', 'style': 'simple', 'explode': False }})
    r"""String used to pick a non-default API version to use"""
    

