"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum

class CustomsDeclarationNonDeliveryOptionEnum(str, Enum):
    r"""Indicates how the carrier should proceed in case the shipment can't be delivered."""
    ABANDON = 'ABANDON'
    RETURN = 'RETURN'
