"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum

class ParcelTemplateAramexAustraliaEnum(str, Enum):
    r"""|Token | Name | Dimensions|
    |:---|:---|:---|
    | Fastway_Australia_Satchel_A2 | Satchel A2 | 594.00 x 420.00 x 48.00 mm|
    | Fastway_Australia_Satchel_A3 | Satchel A3 | 420.00 x 297.00 x 64.00 mm|
    | Fastway_Australia_Satchel_A4 | Satchel A4 | 297.00 x 210.00 x 64.00 mm|
    | Fastway_Australia_Satchel_A5 | Satchel A5 | 210.00 x 148.00 x 64.00 mm|
    """
    FASTWAY_AUSTRALIA_SATCHEL_A2 = 'Fastway_Australia_Satchel_A2'
    FASTWAY_AUSTRALIA_SATCHEL_A3 = 'Fastway_Australia_Satchel_A3'
    FASTWAY_AUSTRALIA_SATCHEL_A4 = 'Fastway_Australia_Satchel_A4'
    FASTWAY_AUSTRALIA_SATCHEL_A5 = 'Fastway_Australia_Satchel_A5'

class ParcelTemplateCouriersPleaseEnum(str, Enum):
    r"""|Token | Name | Dimensions|
    |:---|:---|:---|
    | couriersplease_500g_satchel | 500g Satchel | 22.00 x 33.50 x 0.10 cm|
    | couriersplease_1kg_satchel | 1kg Satchel | 28.00 x 35.00 x 0.10 cm|
    | couriersplease_3kg_satchel | 3kg Satchel | 34.00 x 42.00 x 0.10 cm|
    | couriersplease_5kg_satchel | 5kg Satchel | 43.70 x 59.70 x 0.10 cm|
    """
    COURIERSPLEASE_500G_SATCHEL = 'couriersplease_500g_satchel'
    COURIERSPLEASE_1KG_SATCHEL = 'couriersplease_1kg_satchel'
    COURIERSPLEASE_3KG_SATCHEL = 'couriersplease_3kg_satchel'
    COURIERSPLEASE_5KG_SATCHEL = 'couriersplease_5kg_satchel'

class ParcelTemplateDPDUKEnum(str, Enum):
    r"""|Token | Name | Dimensions|
    |:---|:---|:---|
    | DPD_UK_Express_Pak| DPD UK Express Pak | 530.00 x 400.00 x 100.00 mm|
    """
    DPD_UK_EXPRESS_PAK = 'DPD_UK_Express_Pak'

class ParcelTemplateDHLeCommerceEnum(str, Enum):
    r"""|Token | Name | Dimensions|
    |:---|:---|:---|
    | DHLeC_Irregular | Irregular Shipment | 10.00 x 10.00 x 10.00 in|
    | DHLeC_SM_Flats | Flats | 27.00 x 17.00 x 17.00 in|
    """
    DH_LE_C_IRREGULAR = 'DHLeC_Irregular'
    DH_LE_C_SM_FLATS = 'DHLeC_SM_Flats'

class ParcelTemplateUSPSEnum(str, Enum):
    r"""|Token | Name | Dimensions|
    |:---|:---|:---|
    | USPS_FlatRateCardboardEnvelope | Flat Rate Cardboard Envelope |  12.50 x 9.50 x 0.75 in |
    | USPS_FlatRateEnvelope | Flat Rate Envelope |  12.50 x 9.50 x 0.75 in |
    | USPS_FlatRateGiftCardEnvelope | Flat Rate Gift Card Envelope |  10.00 x 7.00 x 0.75 in |
    | USPS_FlatRateLegalEnvelope | Flat Rate Legal Envelope |  15.00 x 9.50 x 0.75 in |
    | USPS_FlatRatePaddedEnvelope | Flat Rate Padded Envelope |  12.50 x 9.50 x 1.00 in |
    | USPS_FlatRateWindowEnvelope | Flat Rate Window Envelope |  10.00 x 5.00 x 0.75 in |
    | USPS_IrregularParcel | Irregular Parcel |  0.00 x 0.00 x 0.00 in |
    | USPS_LargeFlatRateBoardGameBox | Large Flat Rate Board Game Box |  24.06 x 11.88 x 3.13 in |
    | USPS_LargeFlatRateBox | Large Flat Rate Box |  12.25 x 12.25 x 6.00 in |
    | USPS_APOFlatRateBox | APO/FPO/DPO Large Flat Rate Box |  12.25 x 12.25 x 6.00 in |
    | USPS_LargeVideoFlatRateBox | Flat Rate Large Video Box (Int&#39;l only) |  9.60 x 6.40 x 2.20 in |
    | USPS_MediumFlatRateBox1 | Medium Flat Rate Box 1 |  11.25 x 8.75 x 6.00 in |
    | USPS_MediumFlatRateBox2 | Medium Flat Rate Box 2 |  14.00 x 12.00 x 3.50 in |
    | USPS_RegionalRateBoxA1 | Regional Rate Box A1 |  10.13 x 7.13 x 5.00 in |
    | USPS_RegionalRateBoxA2 | Regional Rate Box A2 |  13.06 x 11.06 x 2.50 in |
    | USPS_RegionalRateBoxB1 | Regional Rate Box B1 |  12.25 x 10.50 x 5.50 in |
    | USPS_RegionalRateBoxB2 | Regional Rate Box B2 |  16.25 x 14.50 x 3.00 in |
    | USPS_SmallFlatRateBox | Small Flat Rate Box |  8.69 x 5.44 x 1.75 in |
    | USPS_SmallFlatRateEnvelope | Small Flat Rate Envelope |  10.00 x 6.00 x 4.00 in |
    | USPS_SoftPack | Soft Pack Padded Envelope |  Length and width defined in the Parcel|
    """
    USPS_FLAT_RATE_CARDBOARD_ENVELOPE = 'USPS_FlatRateCardboardEnvelope'
    USPS_FLAT_RATE_ENVELOPE = 'USPS_FlatRateEnvelope'
    USPS_FLAT_RATE_GIFT_CARD_ENVELOPE = 'USPS_FlatRateGiftCardEnvelope'
    USPS_FLAT_RATE_LEGAL_ENVELOPE = 'USPS_FlatRateLegalEnvelope'
    USPS_FLAT_RATE_PADDED_ENVELOPE = 'USPS_FlatRatePaddedEnvelope'
    USPS_FLAT_RATE_WINDOW_ENVELOPE = 'USPS_FlatRateWindowEnvelope'
    USPS_IRREGULAR_PARCEL = 'USPS_IrregularParcel'
    USPS_LARGE_FLAT_RATE_BOARD_GAME_BOX = 'USPS_LargeFlatRateBoardGameBox'
    USPS_LARGE_FLAT_RATE_BOX = 'USPS_LargeFlatRateBox'
    USPS_APO_FLAT_RATE_BOX = 'USPS_APOFlatRateBox'
    USPS_LARGE_VIDEO_FLAT_RATE_BOX = 'USPS_LargeVideoFlatRateBox'
    USPS_MEDIUM_FLAT_RATE_BOX1 = 'USPS_MediumFlatRateBox1'
    USPS_MEDIUM_FLAT_RATE_BOX2 = 'USPS_MediumFlatRateBox2'
    USPS_REGIONAL_RATE_BOX_A1 = 'USPS_RegionalRateBoxA1'
    USPS_REGIONAL_RATE_BOX_A2 = 'USPS_RegionalRateBoxA2'
    USPS_REGIONAL_RATE_BOX_B1 = 'USPS_RegionalRateBoxB1'
    USPS_REGIONAL_RATE_BOX_B2 = 'USPS_RegionalRateBoxB2'
    USPS_SMALL_FLAT_RATE_BOX = 'USPS_SmallFlatRateBox'
    USPS_SMALL_FLAT_RATE_ENVELOPE = 'USPS_SmallFlatRateEnvelope'
    USPS_SOFT_PACK = 'USPS_SoftPack'

class ParcelTemplateUPSEnum(str, Enum):
    r"""|Token | Name | Dimensions|
    |:---|:---|:---|
    | UPS_Box_10kg | Box 10kg | 410.00 x 335.00 x 265.00 mm|
    | UPS_Box_25kg | Box 25kg | 484.00 x 433.00 x 350.00 mm|
    | UPS_Express_Box | Express Box | 460.00 x 315.00 x 95.00 mm|
    | UPS_Express_Box_Large | Express Box Large | 18.00 x 13.00 x 3.00 in|
    | UPS_Express_Box_Medium | Express Box Medium | 15.00 x 11.00 x 3.00 in|
    | UPS_Express_Box_Small | Express Box Small | 13.00 x 11.00 x 2.00 in|
    | UPS_Express_Envelope | Express Envelope | 12.50 x 9.50 x 2.00 in|
    | UPS_Express_Hard_Pak | Express Hard Pak | 14.75 x 11.50 x 2.00 in|
    | UPS_Express_Legal_Envelope | Express Legal Envelope | 15.00 x 9.50 x 2.00 in|
    | UPS_Express_Pak | Express Pak | 16.00 x 12.75 x 2.00 in|
    | UPS_Express_Tube | Express Tube | 970.00 x 190.00 x 165.00 mm|
    | UPS_Laboratory_Pak | Laboratory Pak | 17.25 x 12.75 x 2.00 in|
    | UPS_MI_BPM | BPM (Mail Innovations - Domestic &amp; International) | 0.00 x 0.00 x 0.00 in|
    | UPS_MI_BPM_Flat | BPM Flat (Mail Innovations - Domestic &amp; International) | 0.00 x 0.00 x 0.00 in|
    | UPS_MI_BPM_Parcel | BPM Parcel (Mail Innovations - Domestic &amp; International) | 0.00 x 0.00 x 0.00 in|
    | UPS_MI_First_Class | First Class (Mail Innovations - Domestic only) | 0.00 x 0.00 x 0.00 in|
    | UPS_MI_Flat | Flat (Mail Innovations - Domestic only) | 0.00 x 0.00 x 0.00 in|
    | UPS_MI_Irregular | Irregular (Mail Innovations - Domestic only) | 0.00 x 0.00 x 0.00 in|
    | UPS_MI_Machinable | Machinable (Mail Innovations - Domestic only) | 0.00 x 0.00 x 0.00 in|
    | UPS_MI_MEDIA_MAIL | Media Mail (Mail Innovations - Domestic only) | 0.00 x 0.00 x 0.00 in|
    | UPS_MI_Parcel_Post | Parcel Post (Mail Innovations - Domestic only) | 0.00 x 0.00 x 0.00 in|
    | UPS_MI_Priority | Priority (Mail Innovations - Domestic only) | 0.00 x 0.00 x 0.00 in|
    | UPS_MI_Standard_Flat | Standard Flat (Mail Innovations - Domestic only) | 0.00 x 0.00 x 0.00 in|
    | UPS_Pad_Pak | Pad Pak | 14.75 x 11.00 x 2.00 in|
    | UPS_Pallet | Pallet | 120.00 x 80.00 x 200.00 cm|
    """
    UPS_BOX_10KG = 'UPS_Box_10kg'
    UPS_BOX_25KG = 'UPS_Box_25kg'
    UPS_EXPRESS_BOX = 'UPS_Express_Box'
    UPS_EXPRESS_BOX_LARGE = 'UPS_Express_Box_Large'
    UPS_EXPRESS_BOX_MEDIUM = 'UPS_Express_Box_Medium'
    UPS_EXPRESS_BOX_SMALL = 'UPS_Express_Box_Small'
    UPS_EXPRESS_ENVELOPE = 'UPS_Express_Envelope'
    UPS_EXPRESS_HARD_PAK = 'UPS_Express_Hard_Pak'
    UPS_EXPRESS_LEGAL_ENVELOPE = 'UPS_Express_Legal_Envelope'
    UPS_EXPRESS_PAK = 'UPS_Express_Pak'
    UPS_EXPRESS_TUBE = 'UPS_Express_Tube'
    UPS_LABORATORY_PAK = 'UPS_Laboratory_Pak'
    UPS_MI_BPM = 'UPS_MI_BPM'
    UPS_MI_BPM_FLAT = 'UPS_MI_BPM_Flat'
    UPS_MI_BPM_PARCEL = 'UPS_MI_BPM_Parcel'
    UPS_MI_FIRST_CLASS = 'UPS_MI_First_Class'
    UPS_MI_FLAT = 'UPS_MI_Flat'
    UPS_MI_IRREGULAR = 'UPS_MI_Irregular'
    UPS_MI_MACHINABLE = 'UPS_MI_Machinable'
    UPS_MI_MEDIA_MAIL = 'UPS_MI_MEDIA_MAIL'
    UPS_MI_PARCEL_POST = 'UPS_MI_Parcel_Post'
    UPS_MI_PRIORITY = 'UPS_MI_Priority'
    UPS_MI_STANDARD_FLAT = 'UPS_MI_Standard_Flat'
    UPS_PAD_PAK = 'UPS_Pad_Pak'
    UPS_PALLET = 'UPS_Pallet'

class ParcelTemplateFedExEnum(str, Enum):
    r"""|Token | Name | Dimensions|
    |:---|:---|:---|
    | FedEx_Box_10kg | FedEx® 10kg Box | 15.81 x 12.94 x 10.19 in|
    | FedEx_Box_25kg | FedEx® 25kg Box | 54.80 x 42.10 x 33.50 in|
    | FedEx_Box_Extra_Large_1 | FedEx® Extra Large Box (X1) | 11.88 x 11.00 x 10.75 in|
    | FedEx_Box_Extra_Large_2 | FedEx® Extra Large Box (X2) | 15.75 x 14.13 x 6.00 in|
    | FedEx_Box_Large_1 | FedEx® Large Box (L1) | 17.50 x 12.38 x 3.00 in|
    | FedEx_Box_Large_2 | FedEx® Large Box (L2) | 11.25 x 8.75 x 7.75 in|
    | FedEx_Box_Medium_1 | FedEx® Medium Box (M1) | 13.25 x 11.50 x 2.38 in|
    | FedEx_Box_Medium_2 | FedEx® Medium Box (M2) | 11.25 x 8.75 x 4.38 in|
    | FedEx_Box_Small_1 | FedEx® Small Box (S1) | 12.38 x 10.88 x 1.50 in|
    | FedEx_Box_Small_2 | FedEx® Small Box (S2) | 11.25 x 8.75 x 4.38 in|
    | FedEx_Envelope | FedEx® Envelope | 12.50 x 9.50 x 0.80 in|
    | FedEx_Padded_Pak | FedEx® Padded Pak | 11.75 x 14.75 x 2.00 in|
    | FedEx_Pak_1 | FedEx® Large Pak | 15.50 x 12.00 x 0.80 in|
    | FedEx_Pak_2 | FedEx® Small Pak | 12.75 x 10.25 x 0.80 in|
    | FedEx_Tube | FedEx® Tube | 38.00 x 6.00 x 6.00 in|
    | FedEx_XL_Pak | FedEx® Extra Large Pak | 17.50 x 20.75 x 2.00 in|
    """
    FED_EX_BOX_10KG = 'FedEx_Box_10kg'
    FED_EX_BOX_25KG = 'FedEx_Box_25kg'
    FED_EX_BOX_EXTRA_LARGE_1 = 'FedEx_Box_Extra_Large_1'
    FED_EX_BOX_EXTRA_LARGE_2 = 'FedEx_Box_Extra_Large_2'
    FED_EX_BOX_LARGE_1 = 'FedEx_Box_Large_1'
    FED_EX_BOX_LARGE_2 = 'FedEx_Box_Large_2'
    FED_EX_BOX_MEDIUM_1 = 'FedEx_Box_Medium_1'
    FED_EX_BOX_MEDIUM_2 = 'FedEx_Box_Medium_2'
    FED_EX_BOX_SMALL_1 = 'FedEx_Box_Small_1'
    FED_EX_BOX_SMALL_2 = 'FedEx_Box_Small_2'
    FED_EX_ENVELOPE = 'FedEx_Envelope'
    FED_EX_PADDED_PAK = 'FedEx_Padded_Pak'
    FED_EX_PAK_1 = 'FedEx_Pak_1'
    FED_EX_PAK_2 = 'FedEx_Pak_2'
    FED_EX_TUBE = 'FedEx_Tube'
    FED_EX_XL_PAK = 'FedEx_XL_Pak'
