"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from dataclasses_json import Undefined, dataclass_json
from shippo import utils
from typing import Optional


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class ServiceGroupAccountAndServiceLevel:
    account_object_id: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('account_object_id'), 'exclude': lambda f: f is None }})
    r"""ID of a Carrier Account object"""
    service_level_token: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('service_level_token'), 'exclude': lambda f: f is None }})
    r"""Service level token, e.g. `usps_priority` or `fedex_ground`.<br>
    See <a href=\"#tag/Service-Levels\">Service Levels</a>.
    """
    

