"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum

class DistanceUnitEnum(str, Enum):
    r"""The measure unit used for length, width and height."""
    CM = 'cm'
    IN = 'in'
    FT = 'ft'
    M = 'm'
    MM = 'mm'
    YD = 'yd'
