"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum

class CustomsDeclarationIncotermEnum(str, Enum):
    r"""The incoterm reference of the shipment. FCA is available for DHL Express and FedEx only.
    eDAP is available for DPD UK only. DAP is available for DHL Express and DPD UK.
    If expecting DAP for other carriers, please use DDU.
    """
    DDP = 'DDP'
    DDU = 'DDU'
    FCA = 'FCA'
    DAP = 'DAP'
    E_DAP = 'eDAP'
